smf/inc/smfplugins/smfcontacts/smfcontactfetcherplugin.h
changeset 5 edb9dc8273d9
parent 3 0446eb7b28aa
--- a/smf/inc/smfplugins/smfcontacts/smfcontactfetcherplugin.h	Thu Apr 15 15:40:08 2010 +0530
+++ b/smf/inc/smfplugins/smfcontacts/smfcontactfetcherplugin.h	Thu Apr 22 15:18:37 2010 +0530
@@ -27,7 +27,7 @@
 #include <smfplace.h>
 
 // Forward declaration
-class SmfPluginManagerUtil;
+class SmfPluginUtil;
 
 /**
  * @ingroup smf_plugin_group
@@ -40,16 +40,15 @@
  */
 class SmfContactFetcherPlugin : public SmfPluginBase
 	{
-	Q_OBJECT
 public:
 	/**
 	 * Constructor with default argument
 	 * @param aUtil The SmfPluginManagerUtil instance. The plugins can 
 	 * call the method getAuthKeys() of this class, with its pluginID to 
 	 * get the OAuth keys, keys are returned only if this plugin is 
 	 * authorised by Smf franework
 	 */
-	SmfContactFetcherPlugin( SmfPluginManagerUtil* aUtil );
+	SmfContactFetcherPlugin( SmfPluginUtil* aUtil );
 	
 	/**
 	 * Destructor
@@ -40,16 +40,15 @@
 	/**
 	 * Constructor with default argument
-	 * @param aUtil The SmfPluginManagerUtil instance. The plugins can 
+	 * @param aUtil The SmfPluginUtil instance. The plugins can 
 	 * call the method getAuthKeys() of this class, with its pluginID to 
 	 * get the OAuth keys, keys are returned only if this plugin is 